.. include:: /_includes/wip_prolog.rst

:mod:`stix.common.confidence` Module
====================================

.. module:: stix.common.confidence

Classes
-------

.. autoclass:: Confidence
	:show-inheritance:
	:members:

.. autoclass:: ConfidenceAssertionChain
	:show-inheritance:
	:members:
